@@ -123,25 +123,27 @@ function init_cms_k8s_resource() {
 
     # Create StorageClass on AKS
     if [[ ${CLOUDPLATFORM} == "AZURE" ]]; then
-      AZURE_STORAGE_ACCOUNT_NAME=$(grep OUTPUT_STORAGEACCOUNT_NAME ${CLOUD_ENV} | awk -F '=' '{print $2}')
       EXISTING_SC=$(kubectl get sc --request-timeout 60s|awk '{print $1}')
-      if [[ -z $EXISTING_SC ]]; then
-        [Error] Can not fetch StorageClass information from the AKS cluster.
-        exit 1
-      fi
-      #Bypass the cms-azure-file SC update if the SC exist!
-      if [[ -z $(echo "$EXISTING_SC"|grep '^cms-azure-file$') ]]; then
 
-      ## [TODO] seperate definition for dev and production mode?
-      #if [[ $DEV_MODE == "false" ]]; then
-      #  SC_SKU="Premium_LRS"
-      #else
-      #  SC_SKU="Standard_LRS"
-      #fi
-      echo "[Info] Creating cms-azure-file StorageClass with storageaccount [$AZURE_STORAGE_ACCOUNT_NAME]."
-
-      # Create AKS StorageClass for all CMS PVC
-      cat <<EOF | kubectl apply -f -
+      if [[ "${USE_AZURE_FILE_STORAGE}" == "true" ]]; then
+        AZURE_STORAGE_ACCOUNT_NAME=$(grep OUTPUT_STORAGEACCOUNT_NAME ${CLOUD_ENV} | awk -F '=' '{print $2}')
+        if [[ -z $EXISTING_SC ]]; then
+          [Error] Can not fetch StorageClass information from the AKS cluster.
+          exit 1
+        fi
+        #Bypass the cms-azure-file SC update if the SC exist!
+        if [[ -z $(echo "$EXISTING_SC"|grep '^cms-azure-file$') ]]; then
+  
+        ## [TODO] seperate definition for dev and production mode?
+        #if [[ $DEV_MODE == "false" ]]; then
+        #  SC_SKU="Premium_LRS"
+        #else
+        #  SC_SKU="Standard_LRS"
+        #fi
+        echo "[Info] Creating cms-azure-file StorageClass with storageaccount [$AZURE_STORAGE_ACCOUNT_NAME]."
+  
+        # Create AKS StorageClass for all CMS PVC
+        cat <<EOF | kubectl apply -f -
 kind: StorageClass
 apiVersion: storage.k8s.io/v1
 metadata:
@@ -162,29 +164,29 @@ parameters:
   storageAccount: $AZURE_STORAGE_ACCOUNT_NAME
   resourcegroup: $RESOURCEGROUP_NAME
 EOF
-      fi # End create StorageClass [cms-azure-disk]
-
-      # Prepare Azure StorageClass for static auzre-file shares
-      prepare_azure_file_static_sc="false"
-      # For upgrade case
-      if [[ -n $(echo "$EXISTING_SC"|grep ^cms-azure-file$) ]]; then
-        if [[ -n $(echo "$EXISTING_SC"|grep ^azure-file-cms-conf$) ]]; then
-          # set to true if the system was fresh installed with static PV SCs.
+        fi # End create StorageClass [cms-azure-file]
+  
+        # Prepare Azure StorageClass for static auzre-file shares
+        prepare_azure_file_static_sc="false"
+        # For upgrade case
+        if [[ -n $(echo "$EXISTING_SC"|grep ^cms-azure-file$) ]]; then
+          if [[ -n $(echo "$EXISTING_SC"|grep ^azure-file-cms-conf$) ]]; then
+            # set to true if the system was fresh installed with static PV SCs.
+            prepare_azure_file_static_sc="true"
+          fi
+        # For fresh installation case
+        else
           prepare_azure_file_static_sc="true"
         fi
-      # For fresh installation case
-      else
-        prepare_azure_file_static_sc="true"
-      fi
-
-      if  [[ "$prepare_azure_file_static_sc" == "true" ]]; then
-        echo "[Info] Start preparing StorageClasses for static azure-file shares."
-        for sharename in $AZUREFILE_SHARES;
-        do
-          # Create StorageClass only when not existing
-          if [[ -z $(echo "$EXISTING_SC"|grep "^azure-file-$sharename$") ]];then
-            echo "[Info] Creating StorageClass azure-file-$sharename."
-            cat <<EOF | kubectl apply -f -
+  
+        if  [[ "$prepare_azure_file_static_sc" == "true" ]]; then
+          echo "[Info] Start preparing StorageClasses for static azure-file shares."
+          for sharename in $AZUREFILE_SHARES;
+          do
+            # Create StorageClass only when not existing
+            if [[ -z $(echo "$EXISTING_SC"|grep "^azure-file-$sharename$") ]];then
+              echo "[Info] Creating StorageClass azure-file-$sharename."
+              cat <<EOF | kubectl apply -f -
 kind: StorageClass
 apiVersion: storage.k8s.io/v1
 metadata:
@@ -207,9 +209,10 @@ parameters:
   resourcegroup: $RESOURCEGROUP_NAME
   shareName: ${sharename}
 EOF
-          fi
-        done
-      fi # End Prepare Azure StorageClass for static auzre-file shares
+            fi
+          done
+        fi # End Prepare Azure StorageClass for static auzre-file shares
+      fi # End USE_AZURE_FILE_STORAGE
 
       #Need to bypass the cms-disk SC update if the SC exist!
       if [[ -z $(echo "$EXISTING_SC"|grep '^cms-disk$') ]]; then
@@ -472,13 +475,15 @@ function reset_products() {
           echo "[Info] Delete CMS StorageClass [cms-azure-file]."
           timeout 10 kubectl get sc|awk '{print $1}'|grep ^cms-azure-file$| xargs kubectl delete sc
         fi
-        for sharename in $AZUREFILE_SHARES;
-        do
-          if [[ -n $(echo "$EXISTING_SC"|grep ^azure-file-$sharename$) ]]; then
-            echo "[Info] Delete CMS StorageClass [azure-file-$sharename]."
-            timeout 10 kubectl get sc|awk '{print $1}'|grep ^azure-file-$sharename$| xargs kubectl delete sc
-          fi
-        done
+        if [[ "${USE_AZURE_FILE_STORAGE}" == "true" ]]; then
+          for sharename in $AZUREFILE_SHARES;
+          do
+            if [[ -n $(echo "$EXISTING_SC"|grep ^azure-file-$sharename$) ]]; then
+              echo "[Info] Delete CMS StorageClass [azure-file-$sharename]."
+              timeout 10 kubectl get sc|awk '{print $1}'|grep ^azure-file-$sharename$| xargs kubectl delete sc
+            fi
+          done
+        fi
       fi
 
       if [[ ${CLOUDPLATFORM} == "GCP" ]]; then
